@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
@@ -10,12 +10,12 @@
 ** This file may be used under the terms of the GNU Lesser
 ** General Public License version 2.1 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
+** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** If you have questions regarding the use of this file, please contact
-** us via http://www.qt-project.org/.
+** us via http://www.qt.io/contact-us/.
 **
 ** $QT_END_LICENSE$
 **
@@ -40,8 +40,6 @@
 #include <QtScript/qscriptstring.h>
 #include <QtScript/qscriptprogram.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -445,6 +443,4 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QScriptEngine::QObjectWrapOptions)
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QSCRIPTENGINE_H
